pub struct DebugScenario {
pub label: String,
pub adapter: String,
pub build: Option<BuildTaskDefinition>,
pub config: String,
pub tcp_connection: Option<TcpArgumentsTemplate>,
}Expand description
Debug Scenario is the user-facing configuration type (used in debug.json). It is still concerned with what to debug and not necessarily how to do it (except for any debug-adapter-specific configuration options).
Fields
label: StringUnsubstituted label for the task.DebugAdapterBinary
adapter: StringName of the Debug Adapter this configuration is intended for.
build: Option<BuildTaskDefinition>An optional build step to be ran prior to starting a debug session. Build steps are used by Zed’s locators to locate the executable to debug.
config: StringJSON-encoded configuration for a given debug adapter.
tcp_connection: Option<TcpArgumentsTemplate>TCP connection parameters (if they were specified by user)